==> scala-k8s-objects_sjs1_2.12-0.1.0-sources.jar: io/k8s/api/core/v1/VolumeMount.scala <==
package io.k8s.api.core.v1


/** VolumeMount describes a mounting of a Volume within a container. */
final case class VolumeMount(
  name : String,
  mountPath : String,
  subPath : Option[String] = None,
  mountPropagation : Option[String] = None,
  readOnly : Option[Boolean] = None,
  subPathExpr : Option[String] = None
) {

  /** Returns a new data with name set to new value */
  def withName(value: String) : VolumeMount = copy(name = value)
  /** transforms name to result of function */
  def mapName(f: String => String) : VolumeMount = copy(name = f(name))

  /** Returns a new data with mountPath set to new value */
  def withMountPath(value: String) : VolumeMount = copy(mountPath = value)
  /** transforms mountPath to result of function */
  def mapMountPath(f: String => String) : VolumeMount = copy(mountPath = f(mountPath))

  /** Returns a new data with subPath set to new value */
  def withSubPath(value: String) : VolumeMount = copy(subPath = Some(value))
  /** if subPath has a value, transforms to the result of function*/
  def mapSubPath(f: String => String) : VolumeMount = copy(subPath = subPath.map(f))

  /** Returns a new data with mountPropagation set to new value */
  def withMountPropagation(value: String) : VolumeMount = copy(mountPropagation = Some(value))
  /** if mountPropagation has a value, transforms to the result of function*/
  def mapMountPropagation(f: String => String) : VolumeMount = copy(mountPropagation = mountPropagation.map(f))

  /** Returns a new data with readOnly set to new value */
  def withReadOnly(value: Boolean) : VolumeMount = copy(readOnly = Some(value))
  /** if readOnly has a value, transforms to the result of function*/
  def mapReadOnly(f: Boolean => Boolean) : VolumeMount = copy(readOnly = readOnly.map(f))

  /** Returns a new data with subPathExpr set to new value */
  def withSubPathExpr(value: String) : VolumeMount = copy(subPathExpr = Some(value))
  /** if subPathExpr has a value, transforms to the result of function*/
  def mapSubPathExpr(f: String => String) : VolumeMount = copy(subPathExpr = subPathExpr.map(f))
}

==> scala-k8s-objects_sjs1_2.12-0.3.0-sources.jar: io/k8s/api/core/v1/VolumeMount.scala <==
package io.k8s.api.core.v1

import dev.hnaderi.k8s.utils._

/** VolumeMount describes a mounting of a Volume within a container. */
final case class VolumeMount(
  name : String,
  mountPath : String,
  subPath : Option[String] = None,
  mountPropagation : Option[String] = None,
  readOnly : Option[Boolean] = None,
  subPathExpr : Option[String] = None
) {

  /** Returns a new data with name set to new value */
  def withName(value: String) : VolumeMount = copy(name = value)
  /** transforms name to result of function */
  def mapName(f: String => String) : VolumeMount = copy(name = f(name))

  /** Returns a new data with mountPath set to new value */
  def withMountPath(value: String) : VolumeMount = copy(mountPath = value)
  /** transforms mountPath to result of function */
  def mapMountPath(f: String => String) : VolumeMount = copy(mountPath = f(mountPath))

  /** Returns a new data with subPath set to new value */
  def withSubPath(value: String) : VolumeMount = copy(subPath = Some(value))
  /** if subPath has a value, transforms to the result of function*/
  def mapSubPath(f: String => String) : VolumeMount = copy(subPath = subPath.map(f))

  /** Returns a new data with mountPropagation set to new value */
  def withMountPropagation(value: String) : VolumeMount = copy(mountPropagation = Some(value))
  /** if mountPropagation has a value, transforms to the result of function*/
  def mapMountPropagation(f: String => String) : VolumeMount = copy(mountPropagation = mountPropagation.map(f))

  /** Returns a new data with readOnly set to new value */
  def withReadOnly(value: Boolean) : VolumeMount = copy(readOnly = Some(value))
  /** if readOnly has a value, transforms to the result of function*/
  def mapReadOnly(f: Boolean => Boolean) : VolumeMount = copy(readOnly = readOnly.map(f))

  /** Returns a new data with subPathExpr set to new value */
  def withSubPathExpr(value: String) : VolumeMount = copy(subPathExpr = Some(value))
  /** if subPathExpr has a value, transforms to the result of function*/
  def mapSubPathExpr(f: String => String) : VolumeMount = copy(subPathExpr = subPathExpr.map(f))
}

object VolumeMount {

    implicit def encoder[T](implicit builder : Builder[T]) : Encoder[io.k8s.api.core.v1.VolumeMount, T] = new Encoder[io.k8s.api.core.v1.VolumeMount, T] {
        def apply(o: io.k8s.api.core.v1.VolumeMount) : T = {
          val obj = ObjectWriter[T]()
          obj
            .write("name", o.name)
            .write("mountPath", o.mountPath)
            .write("subPath", o.subPath)
            .write("mountPropagation", o.mountPropagation)
            .write("readOnly", o.readOnly)
            .write("subPathExpr", o.subPathExpr)
            .build
        }
    }

    implicit def decoderOf[T : Reader] : Decoder[T, VolumeMount] = new Decoder[T, VolumeMount] {
      def apply(t: T): Either[String, VolumeMount] = for {
          obj <- ObjectReader(t)
          name <- obj.read[String]("name")
          mountPath <- obj.read[String]("mountPath")
          subPath <- obj.readOpt[String]("subPath")
          mountPropagation <- obj.readOpt[String]("mountPropagation")
          readOnly <- obj.readOpt[Boolean]("readOnly")
          subPathExpr <- obj.readOpt[String]("subPathExpr")
      } yield VolumeMount (
          name = name,
          mountPath = mountPath,
          subPath = subPath,
          mountPropagation = mountPropagation,
          readOnly = readOnly,
          subPathExpr = subPathExpr
        )
    }
}
